#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
@File    :   nebula.py
@Time    :   2024/11/12 14:15:27
@Author  :   dulip3ng 
@Version :   1.0
@Desc    :   None
'''

from playwright.sync_api import Page
from pages.login_page import LoginPage
from pages.home_page import HomePage
from pages.head_page import HeadPage
from pages.body_page import BodyPage
from pages.list_page import ListPage
from pages.filter_page import FilterPage
from pages.push_page import PushPage

def new_login_page(page: Page):
    return LoginPage(page)

def new_home_page(page: Page):
    return HomePage(page)

def new_head_page(page: Page):
    return HeadPage(page)

def new_body_page(page: Page):
    return BodyPage(page)

def new_list_page(page: Page):
    return ListPage(page)

def new_filter_page(page: Page):
    return FilterPage(page)

def new_push_page(page: Page):
    return PushPage(page)